@@ -14,8 +14,10 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <libintl.h>
 
 #include <gpe/init.h>
@@ -220,6 +222,23 @@ gpe_cal_exit (void)
   gtk_main_quit ();
 }
 
+static int 
+import_one_file(gchar *filename)
+{
+  GError *err = NULL;
+  gchar *content;
+  gsize count;
+  int result = 0;
+	
+  if (g_file_get_contents(filename,&content,&count,&err))
+    {
+      result = import_vcal(content,count);
+      g_free(content);
+    }
+  else
+    result = -1;
+  return result;
+}
 
 static void
 on_import_vcal (GtkWidget *widget, gpointer data)
@@ -231,29 +250,23 @@ on_import_vcal (GtkWidget *widget, gpointer data)
   
   if (gtk_dialog_run(GTK_DIALOG(filesel)) == GTK_RESPONSE_OK)
     {
-      GError *err = NULL;
-      gchar *content, *errstr = NULL;
+      gchar *errstr = NULL;
       int ec = 0, i = 0;
-      gsize count;
       gchar **files = 
         gtk_file_selection_get_selections(GTK_FILE_SELECTION(filesel));
       gtk_widget_hide(filesel); 
       while (files[i])
         {
-          if (g_file_get_contents(files[i],&content,&count,&err))
+          if (import_one_file(files[i]) < 0) 
             {
-              if (import_vcal(content,count) < 0) 
-                {
-                  gchar *tmp;
-                  if (!errstr) 
-                    errstr=g_strdup("");
-                  ec++;
-                  tmp = g_strdup_printf("%s\n%s",errstr,strrchr(files[i],'/')+1);
-                  if (errstr) 
-                     g_free(errstr);
-                  errstr = tmp;
-                }
-              g_free(content);
+              gchar *tmp;
+              if (!errstr) 
+                errstr=g_strdup("");
+              ec++;
+			  tmp = g_strdup_printf("%s\n%s",errstr,strrchr(files[i],'/')+1);
+              if (errstr) 
+                 g_free(errstr);
+              errstr = tmp;
             }
           i++;  
         }
@@ -286,6 +299,18 @@ notebook_switch_page (GtkNotebook *notebook,
   set_time_all_views();
 }
 
+
+static gboolean
+main_window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *data)
+{
+  if (k->string && isalpha(k->string[0]))
+    {
+        new_appointment();
+        return TRUE;
+    }
+  return FALSE;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -297,6 +322,7 @@ main (int argc, char *argv[])
   int option_letter;
   gboolean schedule_only=FALSE;
   extern char *optarg;
+  gchar *ifile = NULL;
 
   if (gpe_application_init (&argc, &argv) == FALSE)
     exit (1);
@@ -318,23 +344,42 @@ main (int argc, char *argv[])
   if (gpe_pim_categories_init () == FALSE)
     exit (1);
 
-  while ((option_letter = getopt (argc, argv, "s:e:")) != -1)
+  while ((option_letter = getopt (argc, argv, "s:e:i:")) != -1)
     {
       if (option_letter == 's')
-	{
-	  skip = atol (optarg);
-	  schedule_only = TRUE;
-	}
+        {
+	      skip = atol (optarg);
+	      schedule_only = TRUE;
+        }
 
       if (option_letter == 'e')
-	uid = atol (optarg);
+        uid = atol (optarg);
+	  if (option_letter == 'i')
+		ifile = optarg;
     }
 
   schedule_next (skip, uid);
 
   if (schedule_only)
     exit (EXIT_SUCCESS);
-
+  
+  if (ifile)
+    {
+	  GtkWidget *dialog;
+      if (import_one_file(ifile))
+        dialog = gtk_message_dialog_new(NULL,0,GTK_MESSAGE_INFO,
+	                                    GTK_BUTTONS_OK,
+	                                    _("Could not import file %s."),
+	                                    ifile);
+	  else
+        dialog = gtk_message_dialog_new(NULL,0,GTK_MESSAGE_INFO,
+	                                      GTK_BUTTONS_OK,
+	                                      _("File %s imported sucessfully."),
+	                                      ifile);
+      gtk_dialog_run(GTK_DIALOG(dialog));
+      exit (EXIT_SUCCESS);
+    }
+	
   for (hour = 0; hour < 24; hour++)
     {
       char buf[32];
@@ -453,6 +498,9 @@ main (int argc, char *argv[])
 
   g_signal_connect(G_OBJECT(notebook),"switch-page",
                    G_CALLBACK(notebook_switch_page),NULL);
+  g_signal_connect (G_OBJECT (main_window), "key_press_event", 
+		    G_CALLBACK (main_window_key_press_event), NULL);
+  gtk_widget_add_events (GTK_WIDGET (main_window), GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
   gtk_widget_show (notebook);
 
